<?php

/**
 * @link https://proficientdesigners.com/
 *
 * @package Proficient Designers Plugin
 * @subpackage pd Woo Tracking Order
 * @since 1.0.0
 * @version 1.0.0
 */

/* Verify the nonce before proceeding. */
if (
	isset($_POST['pd_woo_tracking_order_settings_nonce'])
	&& wp_verify_nonce($_POST['pd_woo_tracking_order_settings_nonce'], 'pd_woo_tracking_order_settings')
) {
	$fields = [
		'tracker_title'				=> sanitize_text_field($_POST['tracker_title']),
		'default_carrier' 			=> sanitize_text_field($_POST['default_carrier']),
		'thankyou_page_visibility' 	=> sanitize_text_field($_POST['thankyou_page_visibility']),
		'order_page_visibility'		=> sanitize_text_field($_POST['order_page_visibility']),
		'tracker_line_color' 		=> sanitize_text_field($_POST['tracker_line_color']),
		'tracker_line_width' 		=> sanitize_text_field($_POST['tracker_line_width']),
		'send_email'				=> sanitize_text_field($_POST['send_email']),
	];

	update_option('_pd_woo_tracking_order_settings', $fields);
	echo '<div class="notice notice-success is-dismissible"><p>New Settings Saved.</p></div>';
}

$carriers_list = get_option('_pd_woo_tracking_order_carriers_list', false);
$pd_woo_settings = get_option('_pd_woo_tracking_order_settings', false);

?>
<form method="POST">
	<div>
		<p>
			<label>
				<b><a>Front end tracker heading</a></b><br>
				<small><em>(You can use placeholders)</em></small>
			</label>
		</p>
		<p>
			<input type="text" name="tracker_title" style="width: 100%" value="<?php echo @$pd_woo_settings['tracker_title'] ?>">
		</p>
	</div>
	<hr>
	<div>
		<p>
			<label>
				<b><a>Choose your default Carrier</a></b><br>
				<small><em>(When you're using a placeholder for carrier's name <code>{{carrier}}</code> this chosen default will be displayed, but anyway you can change it manually by selecting the carrier's dropdown from order page)</em></small>
			</label>
		</p>
		<p>
			<select name="default_carrier">
				<option value="">Choose</option>
				<?php if ($carriers_list) : ?>
					<?php foreach ($carriers_list as $carrier) : ?>
						<option value="<?php echo $carrier ?>" <?php selected(@$pd_woo_settings['default_carrier'], $carrier, true); ?>><?php echo $carrier ?></option>
					<?php endforeach ?>
				<?php endif ?>
			</select>
		</p>
	</div>
	<hr>
	<div>
		<p>
			<label>
				<b><a>Visibility</a></b><br>
				<small><em>(Tracking order map is shown in two places, so choose whether to show it in those respective places or not, by default both are enabled)</em></small>
			</label>
		</p>
		<p>
			<table class="widefat">
				<tr>
					<th><em>Order Thank you Page</em></th>
					<td class="pd-order-status-visibility">
						<label class="switch">
							<input type="checkbox" name="thankyou_page_visibility" <?php checked(@$pd_woo_settings['thankyou_page_visibility'], 'on', true); ?>>
							<span class="slider round"></span>
						</label>
					</td>
				</tr>
				<tr>
					<th><em>View Order Page</em></th>
					<td class="pd-order-status-visibility">
						<label class="switch">
							<input type="checkbox" name="order_page_visibility" <?php checked(@$pd_woo_settings['order_page_visibility'], 'on', true); ?>>
							<span class="slider round"></span>
						</label>
					</td>
				</tr>
			</table>
		</p>
	</div>
	<hr>
	<div>
		<p>
			<label>
				<b><a>Tracker Line</a></b>
			</label>
		</p>
		<p>
			<label>
				<b><i>Color</i></b><br>
				<small><em>(Tracking order map is shown in <span style="color: #0dcc0d"><b>green color</b></span> by default but you can choose your own color from below)</em></small>
			</label>
		</p>
		<p>
			<?php $color = isset($pd_woo_settings['tracker_line_color']) && $pd_woo_settings['tracker_line_color'] !== '' ? $pd_woo_settings['tracker_line_color'] : '#0dcc0d' ?>
			<input name="tracker_line_color" type="text" value="<?php echo $color ?>" class="pd-woo-tracker-color" data-default-color="<?php echo $color ?>" />
		</p>
		<p>
			<label>
				<b><i>Width</i> (Current width: <span id="pd_woo_range_no"><?php echo @$pd_woo_settings['tracker_line_width'] ?></span>)</b><br>
				<small><em>(Tracking order map is shown in <b>6px</b> width by default but you can choose different width sizes from below), also the pointer circle size with change accordingly</em></small>
			</label>
		</p>
		<p>
			<input type="range" name="tracker_line_width" min="0.2" max="0.5" step="0.01" value="<?php echo @$pd_woo_settings['tracker_line_width'] ?>" onchange="document.getElementById('pd_woo_range_no').innerHTML = this.value">
		</p>
	</div>
	<hr>
	<div>
		<p>
			<label>
				<b><a>Send Email for all custom tracking orders</a></b><br>
				<small><em>(Tracking order map default order status & custom order status will be sent as mail to the customers)</em></small>
			</label>
		</p>
		<table class="widefat">
			<tr>
				<th>
					<em><b>Enable / Disable</b></em>
				</th>
				<td class="pd-order-status-visibility">
					<label class="switch">
						<input type="checkbox" name="send_email" <?php checked(@$pd_woo_settings['send_email'], 'on', true); ?>>
						<span class="slider round"></span>
					</label>
				</td>
			</tr>
		</table>
	</div>
	<?php wp_nonce_field('pd_woo_tracking_order_settings', 'pd_woo_tracking_order_settings_nonce'); ?>
	<div style="margin-top: 15px">
		<button type="submit" class="button button-primary">Save Settings</button>
	</div>
</form>