<?php

/**
 * @link https://proficientdesigners.com/
 *
 * @package Proficient Designers Plugin
 * @subpackage pd Woo Tracking Order
 * @since 1.0.0
 * @version 1.0.3
 */

if (!class_exists('pd_Woo_Tracking_Order_Admin')) {

	class pd_Woo_Tracking_Order_Admin extends pd_Woo_Tracking_Send_Email
	{

		public function __construct($plugin_uri)
		{

			if (!current_user_can('manage_woocommerce'))
				return;

			$this->plugin_uri = $plugin_uri;

			add_action('admin_enqueue_scripts', [$this, 'enqueue_admin'], 10, 1);

			add_action('init', [$this, 'cpt']);
			add_action('admin_menu', [$this, 'options_page']);

			add_action('add_meta_boxes', [$this, 'meta_boxes'], 10, 2);
			add_action('save_post', [$this, 'save_order_status_details'], 10, 2);
			add_action('save_post', [$this, 'save_settings_details'], 10, 2);

			add_filter('gettext', [$this, 'change_publish_button'], 10, 2);
			add_filter('the_title', [$this, 'remove_private_prefix']);

			add_action('admin_menu', [$this, 'adjust_the_wp_menu'], 999);

			if ($this->get_current_post_type() === 'pd_tracking_order') {
				add_action('post_row_actions', [$this, 'remove_quick_edit'], 10, 1);
				add_filter('bulk_actions-' . 'edit-pd_tracking_order', [$this, 'edit_bulk_action']);
			}

			/* Filter post updated messages for custom post types. */
			add_filter('post_updated_messages', [$this, 'admin_updated_messages']);
		}

		public function cpt()
		{

			$labels = array(
				'name'                  => _x('pd Tracking Order', 'Post type general name', 'pd-woo-tracking-order'),
				'singular_name'         => _x('pd Tracking Order', 'Post type singular name', 'pd-woo-tracking-order'),
				'menu_name'             => _x('pd Tracking Order', 'Admin Menu text', 'pd-woo-tracking-order'),
				'name_admin_bar'        => _x('pd Tracking Order', 'Add New on Toolbar', 'pd-woo-tracking-order'),
				'add_new'               => __('Add New', 'pd-woo-tracking-order'),
				'add_new_item'          => __('Add New Order Status', 'pd-woo-tracking-order'),
				'new_item'              => __('New Order Status', 'pd-woo-tracking-order'),
				'edit_item'             => __('Edit Order Status', 'pd-woo-tracking-order'),
				'view_item'             => __('View Order Status', 'pd-woo-tracking-order'),
				'all_items'             => __('All Order Statuses', 'pd-woo-tracking-order'),
				'search_items'          => __('Search Order Statuses', 'pd-woo-tracking-order'),
				'parent_item_colon'     => __('Parent Order Statuses:', 'pd-woo-tracking-order'),
				'not_found'             => __('No Order Statuses found.', 'pd-woo-tracking-order'),
				'not_found_in_trash'    => __('No Order Statuses found in Trash.', 'pd-woo-tracking-order'),
				'featured_image'        => _x('pd Tracking Order Cover Image', 'Overrides the “Featured Image” phrase for this post type. Added in 4.3', 'pd-woo-tracking-order'),
				'set_featured_image'    => _x('Set cover image', 'Overrides the “Set featured image” phrase for this post type. Added in 4.3', 'pd-woo-tracking-order'),
				'remove_featured_image' => _x('Remove cover image', 'Overrides the “Remove featured image” phrase for this post type. Added in 4.3', 'pd-woo-tracking-order'),
				'use_featured_image'    => _x('Use as cover image', 'Overrides the “Use as featured image” phrase for this post type. Added in 4.3', 'pd-woo-tracking-order'),
				'archives'              => _x('pd Tracking Order archives', 'The post type archive label used in nav menus. Default “Post Archives”. Added in 4.4', 'pd-woo-tracking-order'),
				'insert_into_item'      => _x('Insert into Order Status', 'Overrides the “Insert into post”/”Insert into page” phrase (used when inserting media into a post). Added in 4.4', 'pd-woo-tracking-order'),
				'uploaded_to_this_item' => _x('Uploaded to this Order Status', 'Overrides the “Uploaded to this post”/”Uploaded to this page” phrase (used when viewing media attached to a post). Added in 4.4', 'pd-woo-tracking-order'),
				'filter_items_list'     => _x('Filter Order Statuses list', 'Screen reader text for the filter links heading on the post type listing screen. Default “Filter posts list”/”Filter pages list”. Added in 4.4', 'pd-woo-tracking-order'),
				'items_list_navigation' => _x('Order Status list navigation', 'Screen reader text for the pagination heading on the post type listing screen. Default “Posts list navigation”/”Pages list navigation”. Added in 4.4', 'pd-woo-tracking-order'),
				'items_list'            => _x('Order Status list', 'Screen reader text for the items list heading on the post type listing screen. Default “Posts list”/”Pages list”. Added in 4.4', 'pd-woo-tracking-order'),
			);
			$args = array(
				'labels'              => $labels,
				'description'         => 'Order status for pd Woo Tracking Order',
				'public'              => false,
				'publicly_queryable'  => false,
				'exclude_from_search' => false,
				'show_ui'             => true,
				'show_in_menu'        => true,
				'show_in_nav_menus'   => false,
				'show_in_admin_bar'   => false,
				'query_var'           => true,
				'rewrite'             => array('slug' => $this->plugin_uri),
				'capability_type'     => 'post',
				'has_archive'         => true,
				'hierarchical'        => false,
				'menu_position'       => 20,
				'supports'            => array('title', 'page-attributes'),
				// 'taxonomies'          => array( 'pd-woo-tracking-order-carriers' ),
				'show_in_rest'        => false,
				'menu_icon'           => $this->menu_icon()
			);

			register_post_type('pd_tracking_order', $args);
		}

		public function menu_icon()
		{

			return file_get_contents(plugin_dir_path(__FILE__) . 'icon.txt');
		}

		public function admin_path($file)
		{

			return plugin_dir_path(dirname(__FILE__)) . 'admin/' . $file;
		}

		public function admin_url($file)
		{

			return plugin_dir_url(dirname(__FILE__)) . 'assets/' . $file;
		}

		public function enqueue_admin()
		{

			wp_enqueue_style('pd-Woo-Tracking-Order', $this->admin_url('css/admin-ui.css'), [], false, 'all');
			wp_enqueue_style('wp-color-picker');
			wp_register_script('pd-Woo-Tracking-Order', $this->admin_url('js/admin.js'), ['jquery', 'jquery-ui-core', 'wp-color-picker'], '1.0', true);
			wp_localize_script('pd-Woo-Tracking-Order', 'pd_woo', [
				'placeholder_json' => $this->admin_url('data/placeholders.json'),
				'ajaxUrl' => admin_url('admin-ajax.php')
			]);
			wp_enqueue_script('pd-Woo-Tracking-Order');
			wp_enqueue_script('jquery-ui-datepicker');
		}

		public function options_page()
		{

			add_submenu_page('edit.php?post_type=pd_tracking_order', 'pd Woo Order Tracking Settings Page', 'Settings', 'manage_woocommerce', $this->plugin_uri . '-settings', [$this, 'options_page_cb'], null);
		}

		public function options_page_cb()
		{

			ob_start();
			require $this->admin_path('settings/main.php');
			ob_get_contents();
		}

		public function meta_boxes()
		{

			add_meta_box('pd-Woo-Tracking-Order-Shop-Meta-Box', 'pd Woo Track Order', [$this, 'shop_order_meta_boxes_cb'], 'shop_order', 'side');
			add_meta_box('pd-Woo-Tracking-Order-Admin-Meta-Box', 'Custom Order Status', [$this, 'custom_order_meta_boxes_cb'], 'pd_tracking_order', 'normal');
			add_meta_box('pd-Woo-Tracking-Order-Placeholders', 'Placeholders', [$this, 'custom_order_placeholder_meta_boxes_cb'], 'pd_tracking_order', 'side');
		}

		public function shop_order_meta_boxes_cb($post)
		{

			ob_start();
			require $this->admin_path('metaboxes/shop-metabox.php');
			ob_get_contents();
		}

		public function custom_order_meta_boxes_cb($post)
		{

			ob_start();
			require $this->admin_path('metaboxes/admin-metabox.php');
			ob_get_contents();
		}

		public function custom_order_placeholder_meta_boxes_cb($post)
		{

			ob_start();
			require $this->admin_path('metaboxes/placeholders.php');
			ob_get_contents();
		}

		public function save_order_status_details($post_id, $post)
		{

			if (!isset($_POST['pd_woo_tracking_details_nonce']) || !wp_verify_nonce($_POST['pd_woo_tracking_details_nonce'], 'pd_woo_tracking_details'))
				return;

			if (get_post_type($post) !== 'shop_order')
				return;

			$order_meta = [
				'send_email' 			=> sanitize_text_field($_POST['send_email']),
				'custom_order_status' 	=> sanitize_text_field($_POST['custom_order_status']),
				'carrier_name' 			=> sanitize_text_field($_POST['carrier_name']),
				'carrier_pickup_date' 	=> sanitize_text_field($_POST['carrier_pickup_date']),
				'carrier_tracking_id' 	=> sanitize_text_field($_POST['carrier_tracking_id']),
			];

			update_post_meta($post_id, '_pd_woo_tracking_order_details', $order_meta);

			parent::send_email_on_order_placed($post_id);
		}

		public function save_settings_details($post_id, $post)
		{

			if (!isset($_POST['pd_woo_order_tracking_status_nonce']))
				return;
			/* Verify the nonce before proceeding. */
			if (!wp_verify_nonce($_POST['pd_woo_order_tracking_status_nonce'], 'pd_woo_order_tracking_status'))
				return;

			if (get_post_type($post) !== 'pd_tracking_order')
				return;

			// wp_mail( 'proficientdesigners@gmail.com', $post_id, '<pre>'.print_r($post, true).'</pre>' );

			$fields = [
				'pd_status_visibility' 			=> sanitize_text_field($_POST['pd_status_visibility']),
				'pd_status_title_ui_past' 		=> sanitize_text_field($_POST['pd_status_title_ui_past']),
				'pd_status_title_ui_present' 	=> sanitize_text_field($_POST['pd_status_title_ui_present']),
				'pd_status_title_ui_future' 	=> sanitize_text_field($_POST['pd_status_title_ui_future']),
				'pd_status_msg_ui_future' 		=> wp_kses_post($_POST['pd_status_msg_ui_future']),
				'pd_status_msg_ui_present' 		=> wp_kses_post($_POST['pd_status_msg_ui_present']),
				'pd_status_msg_ui_past' 		=> wp_kses_post($_POST['pd_status_msg_ui_past']),
				'pd_status_email_subject'		=> sanitize_text_field($_POST['pd_status_email_subject']),
				'pd_status_email_heading' 		=> sanitize_text_field($_POST['pd_status_email_heading']),
				'pd_status_email_msg' 			=> wp_kses_post($_POST['pd_status_email_msg']),
			];

			update_post_meta($post_id, '_pd_woo_order_tracking_status_meta', $fields);
		}

		public function get_current_post_type()
		{

			global $post, $typenow, $current_screen;

			if ($post && $post->post_type) {
				return $post->post_type;
			} else if ($typenow) {
				return $typenow;
			} else if ($current_screen && $current_screen->post_type) {
				return $current_screen->post_type;
			} else if (isset($_REQUEST['post_type'])) {
				return sanitize_key($_REQUEST['post_type']);
			}

			return null;
		}

		public function remove_quick_edit($actions)
		{

			unset($actions['inline hide-if-no-js']);
			return $actions;
		}

		public function change_publish_button($translation, $text)
		{

			if ($this->get_current_post_type() === 'pd_tracking_order') {
				if ($text == 'Publish')
					return 'Save';
			}
			return $translation;
		}

		public function remove_private_prefix($title)
		{

			if (isset($_GET['post_type']) && $_GET['post_type'] === 'pd_tracking_order') {
				$title = str_replace('Private:', '', $title);
			}
			return $title;
		}

		public function adjust_the_wp_menu()
		{

			remove_submenu_page('edit.php?post_type=pd_tracking_order', 'post-new.php?post_type=pd_tracking_order');
		}

		public function edit_bulk_action($actions)
		{

			unset($actions['edit']);
			return $actions;
		}


		function admin_updated_messages($messages)
		{

			global $post, $post_ID;

			if (get_post_type($post) == 'pd_tracking_order') {
				/*Unused 0. Messages start at index 1.*/
				$messages['pd_tracking_order'] = array(
					0 => '',
					1 => sprintf(__('Order status updated.', 'pd-woo-tracking-order')),
					2 => '',
					3 => '',
					4 => __('Order status updated.', 'pd-woo-tracking-order'),
					5 => isset($_GET['revision']) ? sprintf(__('Order status restored to revision from %s', 'pd-woo-tracking-order'), wp_post_revision_title((int) $_GET['revision'], false)) : false,
					6 => sprintf(__('Order status published. <a href="%s">View status</a>', 'pd-woo-tracking-order'), esc_url(get_permalink($post_ID))),
					7 => __('Order status saved.', 'pd-woo-tracking-order'),
					8 => sprintf(__('Order status submitted. <a target="_blank" href="%s">Preview status</a>', 'pd-woo-tracking-order'), esc_url(add_query_arg('preview', 'true', get_permalink($post_ID)))),
					9 => sprintf(__('Order status scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview status</a>', 'pd-woo-tracking-order'), date_i18n(__('M j, Y @ G:i', 'pd-woo-tracking-order'), strtotime($post->post_date)), esc_url(get_permalink($post_ID))),
					10 => sprintf(__('Order status draft updated. <a target="_blank" href="%s">Preview status</a>', 'pd-woo-tracking-order'), esc_url(add_query_arg('preview', 'true', get_permalink($post_ID)))),
				);
			}

			return $messages;
		}
	}
}
