<?php

/**
 * @link https://proficientdesigners.com/
 *
 * @package Proficient Designers Plugin
 * @subpackage pd Woo Tracking Order
 * @since 1.0.0
 * @version 1.0.1
 */

if (!class_exists('pd_Woo_Tracking_Send_Email')) {
	class pd_Woo_Tracking_Send_Email extends pd_Woo_Tracking_Order_Front
	{

		public function __construct()
		{
			add_action('woocommerce_thankyou', [$this, 'send_email_from_thankyou_page'], 10, 1);
		}

		public function get_custom_status_id($status)
		{

			$post = get_page_by_title($status, OBJECT, 'pd_tracking_order');
			return $post->ID;
		}

		public function get_email_heading($order, $post_id)
		{

			@$status_meta = get_post_meta($post_id, '_pd_woo_order_tracking_status_meta')[0];
			return parent::convert_placeholders($order, $status_meta['pd_status_email_heading']);
		}

		public function get_email_subject($order, $post_id)
		{

			@$status_meta = get_post_meta($post_id, '_pd_woo_order_tracking_status_meta')[0];
			return parent::convert_placeholders($order, $status_meta['pd_status_email_subject']);
		}

		public function get_email_message($order, $post_id)
		{

			@$status_meta = get_post_meta($post_id, '_pd_woo_order_tracking_status_meta')[0];
			return parent::convert_placeholders($order, nl2br($status_meta['pd_status_email_msg']));
		}

		public function send_email_from_thankyou_page($order_id)
		{
			/*if custom mail sent already then return*/
			if (get_post_meta($order_id, '_pd_woo_tracking_custom_email', true) !== '1') {
				$this->send_email_on_order_placed($order_id);
			}
		}

		public function send_email_on_order_placed($order_id)
		{
			/*Global settings*/
			@$pd_woo_settings 		= get_option('_pd_woo_tracking_order_settings', false);
			/*Order Settings*/
			@$order_details 		= get_post_meta($order_id, '_pd_woo_tracking_order_details', false)[0];

			$order = wc_get_order($order_id);

			global $woocommerce;
			$mailer 				= $woocommerce->mailer();
			$customer_email 		= $order->get_billing_email();
			$order_status_name 		= isset($order_details['custom_order_status']) ? $order_details['custom_order_status'] : wc_get_order_status_name($order->get_status());

			$custom_status_id 		= $this->get_custom_status_id($order_status_name);
			$email_subject 			= $this->get_email_subject($order, $custom_status_id);
			$email_heading 			= $this->get_email_heading($order, $custom_status_id);
			$email_message 			= $this->get_email_message($order, $custom_status_id);

			$send_email				= isset($order_details['send_email']) ? $order_details['send_email'] : $pd_woo_settings['send_email'];

			$is_permission_granted = ($send_email == 'on') ? true : false;

			if ($is_permission_granted) {
				ob_start();
				wc_get_template('emails/email-header.php', ['email_heading' => $email_heading]);

				echo $email_message;

				wc_get_template('emails/email-footer.php');
				$message = ob_get_clean();

				$mailer->send($customer_email, $email_subject, $message);
				/*addding this to send email once in the thankyou order page*/
				update_post_meta($order_id, '_pd_woo_tracking_custom_email', 1, false);

				return [
					'status' => true,
					'msg' => 'Mail sent!'
				];
			} else {

				return [
					'status' => true,
					'msg' => 'Data saved!'
				];
			}
		}
	}
	new pd_Woo_Tracking_Send_Email();
}
