<?php

/**
 * @link https://proficientdesigners.com/
 *
 * @package Proficient Designers Plugin
 * @subpackage pd Woo Tracking Order
 * @since 1.0.0
 * @version 1.0.4
 */

if (!class_exists('pd_Woo_Tracking_Order_Front')) {

	class pd_Woo_Tracking_Order_Front
	{

		function __construct()
		{
			add_action('wp_enqueue_scripts', [$this, 'enqueue_front_end'], 10, 1);
			add_action('wp_head', [$this, 'css'], 10, 1);

			$pd_woo_settings 	= get_option('_pd_woo_tracking_order_settings', false);

			if ($pd_woo_settings['order_page_visibility'] === 'on') {
				add_action('woocommerce_view_order', [$this, 'tracker_html'], 10, 1);
			}

			if ($pd_woo_settings['thankyou_page_visibility'] === 'on') {
				add_action('woocommerce_thankyou', [$this, 'tracker_html'], 10, 1);
			}
		}

		public function public_path($file)
		{
			return plugin_dir_path(dirname(__FILE__)) . 'front/' . $file;
		}

		public function public_url($file)
		{
			return plugin_dir_url(dirname(__FILE__)) . 'assets/' . $file;
		}

		public function enqueue_front_end()
		{
			wp_enqueue_style('pd-Woo-Tracking-Order', $this->public_url('css/front-ui.css'), [], false, 'all');
			wp_enqueue_script('pd-Woo-Tracking-Order', $this->public_url('js/front.js'), ['jquery'], '1.0.0', true);
		}

		public function get_statuses()
		{
			return new WP_Query([
				'post_type' => 'pd_tracking_order',
				'posts_per_page' => -1,
				'orderby' => 'menu_order',
				'order' => 'asc'
			]);
		}

		public function get_title($order, $order_id)
		{
			$pd_woo_settings 	= get_option('_pd_woo_tracking_order_settings', false);
			$title 				= $this->convert_placeholders($order, $pd_woo_settings['tracker_title']);

			ob_start();
			echo "<h4 class=''>{$title}</h4>";
			ob_get_contents();
		}

		public function statuses($order, $order_id)
		{

			@$order_details 		= get_post_meta($order_id, '_pd_woo_tracking_order_details', false)[0];
			$custom_order_status 	= isset($order_details['custom_order_status']) ? $order_details['custom_order_status'] : wc_get_order_status_name($order->get_status());;

			$statuses = $this->get_statuses();

?>
			<div class="order-tracking-wrapper">
				<?php

				if ($statuses->have_posts()) {
					while ($statuses->have_posts()) {
						$statuses->the_post();

						@$custom_status_visibility_individually = get_post_meta($order_id, '_pd_woo_tracking_order_details')[0];

						$current = ($custom_order_status == get_the_title()) ? 'present' : '';
						@$status_meta = get_post_meta(get_the_ID(), '_pd_woo_order_tracking_status_meta')[0];

						if (isset($custom_status_visibility_individually['custom_order_status_front_visibilty'])) {
							$is_status_individually_selected = in_array(get_the_ID(), $custom_status_visibility_individually['custom_order_status_front_visibilty']);
							$can_this_be_shown = $is_status_individually_selected;
						} else {
							$can_this_be_shown = @$status_meta['pd_status_visibility'];
						}

						if ($can_this_be_shown) :
				?>
							<div class="order-tracking <?php echo $current ?>" data-id="<?php echo get_the_ID() ?>" data-status="<?php echo get_the_title() ?>" data-menuorder="<?php echo get_post_field('menu_order', get_the_ID(), 'display'); ?>">
								<div class="track-line-wrapper">
									<div class="track-line">
										<div class="track-dot"></div>
									</div>
								</div>
								<div class="track-cont">
									<div>
										<div class="track-title" data-past="<?php echo esc_html($this->convert_placeholders($order, @$status_meta['pd_status_title_ui_past'])); ?>" data-present="<?php echo esc_html($this->convert_placeholders($order, @$status_meta['pd_status_title_ui_present'])); ?>" data-future="<?php echo esc_html($this->convert_placeholders($order, @$status_meta['pd_status_title_ui_future'])); ?>"></div>

										<div class="track-txt" data-past="<?php echo esc_html($this->convert_placeholders($order, @$status_meta['pd_status_msg_ui_past'])); ?>" data-present="<?php echo esc_html($this->convert_placeholders($order, @$status_meta['pd_status_msg_ui_present'])); ?>" data-future="<?php echo esc_html($this->convert_placeholders($order, @$status_meta['pd_status_msg_ui_future'])); ?>"></div>
									</div>
								</div>
							</div>

				<?php
						endif;
					}
				}
				?>
			</div>
		<?php
		}

		public function tracker_html($order_id)
		{
			$order = wc_get_order($order_id);
			$this->get_title($order, $order_id);
			$this->statuses($order, $order_id);
		}

		public function convert_placeholders($order, $string)
		{

			$json_data 			= file_get_contents(plugin_dir_path(dirname(__FILE__)) . '/assets/data/placeholders.json');
			$encoded 			= json_decode($json_data);

			$order_id 			= $order->get_id();
			@$pd_woo_settings 	= get_option('_pd_woo_tracking_order_settings', false);
			@$order_details 	= get_post_meta($order_id, '_pd_woo_tracking_order_details', false)[0];

			$converters = [];
			foreach ($encoded as $section) {
				$lists = $section->lists;

				foreach ($lists as $list) {
					if (isset($list->func)) {
						$function = $list->func;

						if (is_numeric(strrpos($list->placeholder, '{{date_'))) {
							$converters[$list->placeholder] = date_i18n(get_option('date_format') . ' @ ' . get_option('time_format'), strtotime($order->$function()), false);
						} else {
							$converters[$list->placeholder] = $order->$function();
						}
					} else if (isset($list->custom_func)) {
						$function = $list->custom_func;
						$converters[$list->placeholder] = $this->$function($pd_woo_settings, $order_details);
					}
				}
			}

			return strtr($string, $converters);
		}

		public function pd_woo_tracking_order_get_carrier($default, $value)
		{
			$default_carrier = isset($default['default_carrier']) && !empty($default['default_carrier']) ? $default['default_carrier'] : '';
			return isset($value['carrier_name']) ? $value['carrier_name'] : $default_carrier;
		}

		public function pd_woo_tracking_order_get_carrier_tracking($default, $value)
		{
			return isset($value['carrier_tracking_id']) ? $value['carrier_tracking_id'] : '';
		}

		public function pd_woo_tracking_order_get_carrier_pickup_date($default, $value)
		{
			return isset($value['carrier_pickup_date']) ? $value['carrier_pickup_date'] : '';
		}

		public function css()
		{
			$track_line_color = $this->check_value_isset('tracker_line_color', '#0dcc0d');
			$track_line_width = $this->check_value_isset('tracker_line_width', '2rem');
		?>
			<style type="text/css">
				.order-tracking-wrapper .order-tracking.passed .track-line-wrapper .track-line {
					background-color: <?php echo $track_line_color ?>
				}

				.order-tracking-wrapper .order-tracking.passed .track-line-wrapper .track-line .track-dot {
					background-color: <?php echo $track_line_color ?>
				}

				.order-tracking-wrapper .order-tracking .track-line-wrapper .track-line {
					width: <?php echo $track_line_width ?>rem;
				}

				.order-tracking-wrapper .order-tracking .track-line-wrapper .track-line .track-dot {
					width: calc(<?php echo $track_line_width ?>rem * 3);
					height: calc(<?php echo $track_line_width ?>rem * 3);
				}
			</style>
<?php
		}

		public function check_value_isset($key, $default)
		{
			@$pd_woo_settings = get_option('_pd_woo_tracking_order_settings', false);

			if (isset($pd_woo_settings[$key]) && !empty($pd_woo_settings[$key])) {
				return $pd_woo_settings[$key];
			} else {
				return $default;
			}
		}
	}
}
